summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetepasswordedaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetepasswordedaccount.h')
-rw-r--r--kopete/libkopete/kopetepasswordedaccount.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kopete/libkopete/kopetepasswordedaccount.h b/kopete/libkopete/kopetepasswordedaccount.h
index 1534025d..d008bae4 100644
--- a/kopete/libkopete/kopetepasswordedaccount.h
+++ b/kopete/libkopete/kopetepasswordedaccount.h
@@ -49,7 +49,7 @@ public:
*
* @deprecated Use the constructor that specifies if a blank password is allowed
*/
- PasswordedAccount( Protocol *parent, const QString &acctId, uint maxPasswordLength = 0, const char *name = 0 );
+ PasswordedAccount( Protocol *parent, const TQString &acctId, uint maxPasswordLength = 0, const char *name = 0 );
/**
* KopetePasswordedAccount constructor
@@ -60,7 +60,7 @@ public:
*
* @param name The name for this QObject
*/
- PasswordedAccount( Protocol *parent, const QString &acctId, uint maxPasswordLength = 0,
+ PasswordedAccount( Protocol *parent, const TQString &acctId, uint maxPasswordLength = 0,
bool allowBlankPassword = false, const char *name = 0 );
virtual ~PasswordedAccount();
@@ -99,10 +99,10 @@ public:
public slots:
/**
* Called when your account should attempt to connect.
* @param password The password to connect with, or QString::null
* if the user wished to cancel the connection attempt.
*/
- virtual void connectWithPassword( const QString &password ) = 0;
+ virtual void connectWithPassword( const TQString &password ) = 0;
protected:
/**
@@ -110,7 +110,7 @@ protected:
* The default implementation should be adequate in most cases; override
* if you have a custom message to show the user.
*/
- virtual QString passwordPrompt();
+ virtual TQString passwordPrompt();
protected slots:
/**
@@ -99,10 +99,10 @@ public:
/**
* Called when your account should attempt to connect.
- * @param password The password to connect with, or QString::null
+ * @param password The password to connect with, or TQString::null
* if the user wished to cancel the connection attempt.
*/